@@ -1,5 +1,4 @@
-#' Plots the P-Value (Consonance), S-value (Surprisal),
-#' and Likelihood Function via ggplot2
+#' Plots Consonance, Surprisal, and Likelihood Functions
 #'
 #' Takes the dataframe produced by the interval functions and
 #' plots the p-values/s-values, consonance (confidence) levels, and
@@ -62,7 +61,7 @@
 #' By default, it is set to fill = "#239a98". The inputs must be in quotes. For example,
 #' ggcurve(type = "c", data = x, fill = "#333333").
 #'
-#' @return Plot with intervals at every consonance level graphed with their corresponding
+#' @return A plot with intervals at every consonance level graphed with their corresponding
 #' p-values and compatibility levels.
 #'
 #' @examples
@@ -77,12 +76,15 @@
 #' RandomData <- data.frame(GroupA, GroupB)
 #'
 #' intervalsdf <- curve_mean(GroupA, GroupB, data = RandomData, method = "default")
-#' (function1 <- ggcurve(type = "c", intervalsdf[[1]]))
+#' ggcurve(type = "c", intervalsdf[[1]], nullvalue = TRUE)
+#' @seealso [plot_compare()]
+#'
+
 ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullvalue = FALSE, position = "pyramid",
                     title = "Interval Function",
                     subtitle = "The function displays intervals at every level.",
                     xaxis = expression(Theta ~ "Range of Values"),
-                    yaxis = "P-value",
+                    yaxis = expression(paste(italic(p), "-value")),
                     color = "#000000",
                     fill = "#239a98") {
 
@@ -112,9 +114,6 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       stop("Error: 'subtitle' must be a string.")
     }
 
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
@@ -137,8 +136,8 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       geom_line(aes(x = upper.limit, y = pvalue),
         color = color
       ) +
-      geom_point(data = interval, mapping = aes(x = limits, y = 1 - levels), size = .95) +
-      geom_line(data = interval, mapping = aes(x = limits, y = 1 - levels, group = levels), size = .40) +
+      geom_point(data = interval, mapping = aes(x = limits, y = 1 - levels), size = 1.75, shape = 18) +
+      geom_line(data = interval, mapping = aes(x = limits, y = 1 - levels, group = levels), size = .30) +
       geom_ribbon(aes(x = lower.limit, ymin = min(pvalue), ymax = pvalue),
         fill = fill, alpha = 0.20
       ) +
@@ -146,12 +145,12 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
         fill = fill, alpha = 0.20
       ) +
       labs(
-        title = "Consonance Function",
+        title = "Consonance Curve",
         subtitle = subtitle,
         x = xaxis,
         y = yaxis
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 12),
         plot.subtitle = element_text(size = 11),
@@ -168,7 +167,7 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (position == "inverted") {
           scale_y_reverse(
-            expand = expand_scale(mult = c(0.01, 0.025)),
+            expand = expansion(mult = c(0.01, 0.025)),
             breaks = seq(0, 1, 0.10),
             sec.axis = sec_axis(~ (1 - .) * 100, name = "Levels for CI (%)", breaks = seq(0, 100, 10))
           )
@@ -177,7 +176,7 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (position == "pyramid") {
           scale_y_continuous(
-            expand = expand_scale(mult = c(0.01, 0.025)),
+            expand = expansion(mult = c(0.01, 0.025)),
             breaks = seq(0, 1, 0.10),
             sec.axis = sec_axis(~ (1 - .) * 100, name = "Levels for CI (%)", breaks = seq(0, 100, 10))
           )
@@ -187,12 +186,12 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
@@ -216,9 +215,6 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
@@ -240,13 +236,13 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       geom_line(aes(x = upper.limit, y = svalue),
         color = color
       ) +
-      geom_point(data = interval, mapping = aes(x = limits, y = (-log2(1 - levels))), size = .95) +
-      geom_line(data = interval, mapping = aes(x = limits, y = (-log2(1 - levels)), group = levels), size = .40) +
+      geom_point(data = interval, mapping = aes(x = limits, y = (-log2(1 - levels))), size = 1.75, shape = 18) +
+      geom_line(data = interval, mapping = aes(x = limits, y = (-log2(1 - levels)), group = levels), size = .30) +
       geom_ribbon(aes(x = lower.limit, ymin = max(svalue), ymax = svalue),
-        fill = fill, alpha = 0.30
+        fill = fill, alpha = 0.20
       ) +
       geom_ribbon(aes(x = upper.limit, ymin = max(svalue), ymax = svalue),
-        fill = fill, alpha = 0.30
+        fill = fill, alpha = 0.20
       ) +
       labs(
         title = "Surprisal Function",
@@ -254,7 +250,7 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
         x = xaxis,
         y = "S-value \n(Bits of Information)"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 12),
         plot.subtitle = element_text(size = 11),
@@ -295,23 +291,20 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = x)) +
-      stat_ecdf(geom = "point", color = fill, size = 0.70, shape = 8, alpha = 0.3) +
-      geom_hline(yintercept = 0.50) +
+      stat_ecdf(geom = "point", color = fill, size = 0.75, shape = 5, alpha = 0.75) +
+      geom_hline(yintercept = 0.50, linetype = "dotted") +
       labs(
         title = "Consonance Distribution",
         subtitle = subtitle,
         x = xaxis,
         y = "Cumulative Confidence"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
@@ -323,17 +316,17 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (measure == "ratio") scale_x_log10(breaks = scales::pretty_breaks(n = 10))
       } +
-      scale_y_continuous(expand = expand_scale(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
+      scale_y_continuous(expand = expansion(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
       if (nullvalue == TRUE) {
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
@@ -349,22 +342,19 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = x)) +
-      geom_density(fill = fill, alpha = 0.3) +
+      geom_density(fill = fill, alpha = 0.20) +
       labs(
         title = "Consonance Density",
         subtitle = subtitle,
         x = xaxis,
         y = "Density"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
@@ -376,17 +366,17 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (measure == "ratio") scale_x_log10(breaks = scales::pretty_breaks(n = 10))
       } +
-      scale_y_continuous(expand = expand_scale(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
+      scale_y_continuous(expand = expansion(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
       if (nullvalue == TRUE) {
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
@@ -408,23 +398,20 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = values, y = support)) +
       geom_line() +
-      geom_ribbon(aes(x = values, ymin = min(support), ymax = support), fill = "#239a98", alpha = 0.30) +
+      geom_ribbon(aes(x = values, ymin = min(support), ymax = support), fill = "#239a98", alpha = 0.20) +
       labs(
         title = "Relative Likelihood Function",
         subtitle = subtitle,
         x = xaxis,
         y = "Relative Likelihood"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
@@ -436,22 +423,22 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (measure == "ratio") scale_x_log10(breaks = scales::pretty_breaks(n = 10))
       } +
-      scale_y_continuous(expand = expand_scale(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
+      scale_y_continuous(expand = expansion(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
       if (nullvalue == TRUE) {
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
 
-    # Log Likelihood Function -----------------------------------------------------
+    # Log-Likelihood Function -----------------------------------------------------
   } else if (type == "l2") {
     if (ncol(data) != 5) {
       stop("Error: 'data' must be a data frame from 'concurve'.")
@@ -468,23 +455,20 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = values, y = loglikelihood)) +
       geom_line() +
-      geom_ribbon(aes(x = values, ymin = min(loglikelihood), ymax = loglikelihood), fill = "#239a98", alpha = 0.30) +
+      geom_ribbon(aes(x = values, ymin = min(loglikelihood), ymax = loglikelihood), fill = "#239a98", alpha = 0.20) +
       labs(
-        title = "Log Likelihood Function",
+        title = "Log-Likelihood Function",
         subtitle = subtitle,
         x = xaxis,
-        y = "Log Likelihood"
+        y = "Log-Likelihood"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
@@ -496,17 +480,17 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (measure == "ratio") scale_x_log10(breaks = scales::pretty_breaks(n = 10))
       } +
-      scale_y_continuous(expand = expand_scale(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
+      scale_y_continuous(expand = expansion(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
       if (nullvalue == TRUE) {
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
@@ -528,23 +512,20 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = values, y = likelihood)) +
       geom_line() +
-      geom_ribbon(aes(x = values, ymin = min(likelihood), ymax = likelihood), fill = "#239a98", alpha = 0.30) +
+      geom_ribbon(aes(x = values, ymin = min(likelihood), ymax = likelihood), fill = "#239a98", alpha = 0.20) +
       labs(
         title = "Likelihood Function",
         subtitle = subtitle,
         x = xaxis,
         y = "Likelihood"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
@@ -556,17 +537,17 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
       {
         if (measure == "ratio") scale_x_log10(breaks = scales::pretty_breaks(n = 10))
       } +
-      scale_y_continuous(expand = expand_scale(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
+      scale_y_continuous(expand = expansion(mult = c(0.01, 0.05)), breaks = scales::pretty_breaks(n = 10)) +
       if (nullvalue == TRUE) {
         if (measure == "default") {
           annotate("segment",
             x = 0, xend = 0, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         } else if (measure == "ratio") {
           annotate("segment",
             x = 1, xend = 1, y = 0, yend = 1,
-            color = "#990000", alpha = 0.3, size = .75, linetype = 1
+            color = "#990000", alpha = 0.4, size = .75, linetype = 3
           )
         }
       }
@@ -588,23 +569,20 @@ ggcurve <- function(data, type = "c", measure = "default", levels = 0.95, nullva
     if (is.character(subtitle) != TRUE) {
       stop("Error: 'subtitle' must be a string.")
     }
-    if (is.character(yaxis) != TRUE) {
-      stop("Error: 'yaxis' must be a string.")
-    }
     if (is.character(fill) != TRUE) {
       stop("Error: 'fill' must be a string for the color.")
     }
 
     ggplot(data = data, mapping = aes(x = values, y = deviancestat)) +
       geom_line() +
-      geom_ribbon(aes(x = values, ymin = deviancestat, ymax = max(deviancestat)), fill = "#239a98", alpha = 0.30) +
+      geom_ribbon(aes(x = values, ymin = deviancestat, ymax = max(deviancestat)), fill = "#239a98", alpha = 0.20) +
       labs(
         title = "Deviance Function",
         subtitle = subtitle,
         x = xaxis,
         y = "Deviance Statistic"
       ) +
-      theme_bw() +
+      theme_minimal() +
       theme(
         plot.title = element_text(size = 14),
         plot.subtitle = element_text(size = 12),
